==> ogre-docs-1.11.2-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/manual.js <==
var manual =
[
    [ "Introduction", "_introduction.html", null ],
    [ "The Core Objects", "_the-_core-_objects.html", [
      [ "The Root object", "_the-_core-_objects.html#The-Root-Object", null ],
      [ "The RenderSystem object", "_the-_core-_objects.html#The-RenderSystem-object", null ],
      [ "The SceneManager object", "_the-_core-_objects.html#The-SceneManager-object", null ],
      [ "The ResourceGroupManager Object", "_the-_core-_objects.html#The-ResourceGroupManager-Object", null ],
      [ "The Mesh Object", "_the-_core-_objects.html#The-Mesh-Object", null ],
      [ "Entities", "_the-_core-_objects.html#Entities", null ],
      [ "Materials", "_the-_core-_objects.html#Materials", null ],
      [ "Overlays", "_the-_core-_objects.html#Overlays", null ]
    ] ],
    [ "Scripts", "_scripts.html", "_scripts" ],
    [ "High-level Programs", "_high-level-_programs.html", [
      [ "Cg programs", "_high-level-_programs.html#Cg", null ],
      [ "DirectX9 HLSL", "_high-level-_programs.html#HLSL", null ],
      [ "OpenGL GLSL", "_high-level-_programs.html#GLSL", [
        [ "GLSL Texture Samplers", "_high-level-_programs.html#GLSL-Texture-Samplers", null ],
        [ "Matrix parameters", "_high-level-_programs.html#Matrix-parameters", null ],
        [ "Accessing OpenGL states in GLSL", "_high-level-_programs.html#Accessing-OpenGL-states-in-GLSL", null ],
        [ "Binding vertex attributes", "_high-level-_programs.html#Binding-vertex-attributes", null ],
        [ "Preprocessor definitions", "_high-level-_programs.html#Preprocessor-definitions", null ],
        [ "GLSL Geometry shader specification", "_high-level-_programs.html#GLSL-Geometry-shader-specification", null ]
      ] ],
      [ "Unified High-level Programs", "_high-level-_programs.html#Unified-High_002dlevel-Programs", null ],
      [ "Using GPU Programs in a Pass", "_high-level-_programs.html#Using-Vertex_002fGeometry_002fFragment-Programs-in-a-Pass", [
        [ "Parameter specification", "_high-level-_programs.html#Program-Parameter-Specification", null ]
      ] ],
      [ "Shadows and Vertex Programs", "_high-level-_programs.html#Shadows-and-Vertex-Programs", null ],
      [ "Skeletal Animation in Vertex Programs", "_high-level-_programs.html#Skeletal-Animation-in-Vertex-Programs", null ],
      [ "Morph Animation in Vertex Programs", "_high-level-_programs.html#Morph-Animation-in-Vertex-Programs", null ],
      [ "Pose Animation in Vertex Programs", "_high-level-_programs.html#Pose-Animation-in-Vertex-Programs", null ],
      [ "Vertex texture fetching in vertex programs", "_high-level-_programs.html#Vertex-texture-fetching-in-vertex-programs", null ],
      [ "Vertex Texture Fetch", "_high-level-_programs.html#Vertex-Texture-Fetch", null ]
    ] ],
    [ "Runtime Shader Generation", "_runtime-_shader-_generation.html", "_runtime-_shader-_generation" ],
    [ "Mesh Tools", "_mesh-_tools.html", [
      [ "Exporters", "_mesh-_tools.html#Exporters", null ],
      [ "XMLConverter", "_mesh-_tools.html#XMLConverter", null ],
      [ "MeshUpgrader", "_mesh-_tools.html#MeshUpgrader", null ]
    ] ],
    [ "Hardware Buffers", "_hardware-_buffers.html", [
      [ "Buffer Usage", "_hardware-_buffers.html#Buffer-Usage", [
        [ "Shadow Buffers", "_hardware-_buffers.html#Shadow-Buffers", null ],
        [ "Locking buffers", "_hardware-_buffers.html#Locking-buffers", null ],
        [ "Practical Buffer Tips", "_hardware-_buffers.html#Practical-Buffer-Tips", null ]
      ] ],
      [ "Hardware Vertex Buffers", "_hardware-_buffers.html#Hardware-Vertex-Buffers", [
        [ "The VertexData class", "_hardware-_buffers.html#The-VertexData-class", null ],
        [ "Vertex Declarations", "_hardware-_buffers.html#Vertex-Declarations", null ],
        [ "Important Considerations", "_hardware-_buffers.html#Important-Considerations", null ],
        [ "Vertex Buffer Bindings", "_hardware-_buffers.html#Vertex-Buffer-Bindings", null ],
        [ "Creating the Vertex Buffer", "_hardware-_buffers.html#Creating-the-Vertex-Buffer", null ],
        [ "Binding the Vertex Buffer", "_hardware-_buffers.html#Binding-the-Vertex-Buffer", null ],
        [ "Updating Vertex Buffers", "_hardware-_buffers.html#Updating-Vertex-Buffers", null ]
      ] ],
      [ "Hardware Index Buffers", "_hardware-_buffers.html#Hardware-Index-Buffers", [
        [ "The IndexData class", "_hardware-_buffers.html#The-IndexData-class", null ],
        [ "Updating Index Buffers", "_hardware-_buffers.html#Updating-Index-Buffers", null ]
      ] ],
      [ "Hardware Pixel Buffers", "_hardware-_buffers.html#Hardware-Pixel-Buffers", [
        [ "Textures", "_hardware-_buffers.html#Textures", [
          [ "Creating a texture", "_hardware-_buffers.html#Creating-a-texture", null ]
        ] ],
        [ "Getting a PixelBuffer", "_hardware-_buffers.html#Getting-a-PixelBuffer", null ],
        [ "Updating Pixel Buffers", "_hardware-_buffers.html#Updating-Pixel-Buffers", null ],
        [ "Blit from memory", "_hardware-_buffers.html#blitFromMemory", null ],
        [ "Direct memory locking", "_hardware-_buffers.html#Direct-memory-locking", null ],
        [ "Texture Types", "_hardware-_buffers.html#Texture-Types", null ],
        [ "Cube map textures", "_hardware-_buffers.html#Cube-map-textures", null ],
        [ "Pixel Formats", "_hardware-_buffers.html#Pixel-Formats", null ],
        [ "Colour channels", "_hardware-_buffers.html#Colour-channels", null ],
        [ "List of pixel formats", "_hardware-_buffers.html#Complete-list-of-pixel-formats", null ],
        [ "Pixel boxes", "_hardware-_buffers.html#Pixel-boxes", null ]
      ] ]
    ] ],
    [ "Shadows", "_shadows.html", [
      [ "Enabling shadows", "_shadows.html#Enabling-shadows", null ],
      [ "Opting out of shadows", "_shadows.html#Opting-out-of-shadows", null ],
      [ "Stencil Shadows", "_shadows.html#Stencil-Shadows", null ],
      [ "Texture-based Shadows", "_shadows.html#Texture_002dbased-Shadows", null ],
      [ "Configuring Texture Shadows", "_shadows.html#Configuring-Texture-Shadows", [
        [ "Integrated Texture Shadows", "_shadows.html#Integrated-Texture-Shadows", null ]
      ] ],
      [ "Modulative Shadows", "_shadows.html#Modulative-Shadows", null ],
      [ "Additive Light Masking", "_shadows.html#Additive-Light-Masking", null ]
    ] ],
    [ "Animation", "_animation.html", [
      [ "Skeletal Animation", "_animation.html#Skeletal-Animation", null ],
      [ "Vertex Animation", "_animation.html#Vertex-Animation", null ],
      [ "SceneNode Animation", "_animation.html#SceneNode-Animation", null ],
      [ "Numeric Value Animation", "_animation.html#Numeric-Value-Animation", null ]
    ] ]
];

==> ogre-docs-1.11.5-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/manual.js <==
var manual =
[
    [ "Introduction", "_introduction.html", null ],
    [ "The Core Objects", "_the-_core-_objects.html", [
      [ "The Root object", "_the-_core-_objects.html#The-Root-Object", null ],
      [ "The RenderSystem object", "_the-_core-_objects.html#The-RenderSystem-object", null ],
      [ "The SceneManager object", "_the-_core-_objects.html#The-SceneManager-object", null ],
      [ "The ResourceGroupManager Object", "_the-_core-_objects.html#The-ResourceGroupManager-Object", null ],
      [ "The Mesh Object", "_the-_core-_objects.html#The-Mesh-Object", null ],
      [ "Entities", "_the-_core-_objects.html#Entities", null ],
      [ "Materials", "_the-_core-_objects.html#Materials", null ],
      [ "Overlays", "_the-_core-_objects.html#Overlays", null ]
    ] ],
    [ "Resource Management", "_resource-_management.html", [
      [ "Resource Life-cycle", "_resource-_management.html#Resource-Life-cycle", null ],
      [ "Locations", "_resource-_management.html#Resource-Location", null ],
      [ "Groups", "_resource-_management.html#Resource-Groups", [
        [ "Resource-Declaration", "_resource-_management.html#Resource-Declaration", null ]
      ] ]
    ] ],
    [ "Scripts", "_scripts.html", "_scripts" ],
    [ "High-level Programs", "_high-level-_programs.html", [
      [ "Cg programs", "_high-level-_programs.html#Cg", null ],
      [ "DirectX9 HLSL", "_high-level-_programs.html#HLSL", null ],
      [ "OpenGL GLSL", "_high-level-_programs.html#GLSL", [
        [ "GLSL Texture Samplers", "_high-level-_programs.html#GLSL-Texture-Samplers", null ],
        [ "Matrix parameters", "_high-level-_programs.html#Matrix-parameters", null ],
        [ "Accessing OpenGL states in GLSL", "_high-level-_programs.html#Accessing-OpenGL-states-in-GLSL", null ],
        [ "Binding vertex attributes", "_high-level-_programs.html#Binding-vertex-attributes", null ],
        [ "Preprocessor definitions", "_high-level-_programs.html#Preprocessor-definitions", null ],
        [ "GLSL Geometry shader specification", "_high-level-_programs.html#GLSL-Geometry-shader-specification", null ]
      ] ],
      [ "Unified High-level Programs", "_high-level-_programs.html#Unified-High_002dlevel-Programs", null ],
      [ "Using GPU Programs in a Pass", "_high-level-_programs.html#Using-Vertex_002fGeometry_002fFragment-Programs-in-a-Pass", [
        [ "Parameter specification", "_high-level-_programs.html#Program-Parameter-Specification", null ]
      ] ],
      [ "Shadows and Vertex Programs", "_high-level-_programs.html#Shadows-and-Vertex-Programs", null ],
      [ "Skeletal Animation in Vertex Programs", "_high-level-_programs.html#Skeletal-Animation-in-Vertex-Programs", null ],
      [ "Morph Animation in Vertex Programs", "_high-level-_programs.html#Morph-Animation-in-Vertex-Programs", null ],
      [ "Pose Animation in Vertex Programs", "_high-level-_programs.html#Pose-Animation-in-Vertex-Programs", null ],
      [ "Vertex texture fetching in vertex programs", "_high-level-_programs.html#Vertex-texture-fetching-in-vertex-programs", null ],
      [ "Vertex Texture Fetch", "_high-level-_programs.html#Vertex-Texture-Fetch", null ]
    ] ],
    [ "Runtime Shader Generation", "_runtime-_shader-_generation.html", "_runtime-_shader-_generation" ],
    [ "Mesh Tools", "_mesh-_tools.html", [
      [ "Exporters", "_mesh-_tools.html#Exporters", null ],
      [ "XMLConverter", "_mesh-_tools.html#XMLConverter", null ],
      [ "MeshUpgrader", "_mesh-_tools.html#MeshUpgrader", null ]
    ] ],
    [ "Hardware Buffers", "_hardware-_buffers.html", [
      [ "Buffer Usage", "_hardware-_buffers.html#Buffer-Usage", [
        [ "Shadow Buffers", "_hardware-_buffers.html#Shadow-Buffers", null ],
        [ "Locking buffers", "_hardware-_buffers.html#Locking-buffers", null ],
        [ "Practical Buffer Tips", "_hardware-_buffers.html#Practical-Buffer-Tips", null ]
      ] ],
      [ "Hardware Vertex Buffers", "_hardware-_buffers.html#Hardware-Vertex-Buffers", [
        [ "The VertexData class", "_hardware-_buffers.html#The-VertexData-class", null ],
        [ "Vertex Declarations", "_hardware-_buffers.html#Vertex-Declarations", null ],
        [ "Important Considerations", "_hardware-_buffers.html#Important-Considerations", null ],
        [ "Vertex Buffer Bindings", "_hardware-_buffers.html#Vertex-Buffer-Bindings", null ],
        [ "Creating the Vertex Buffer", "_hardware-_buffers.html#Creating-the-Vertex-Buffer", null ],
        [ "Binding the Vertex Buffer", "_hardware-_buffers.html#Binding-the-Vertex-Buffer", null ],
        [ "Updating Vertex Buffers", "_hardware-_buffers.html#Updating-Vertex-Buffers", null ]
      ] ],
      [ "Hardware Index Buffers", "_hardware-_buffers.html#Hardware-Index-Buffers", [
        [ "The IndexData class", "_hardware-_buffers.html#The-IndexData-class", null ],
        [ "Updating Index Buffers", "_hardware-_buffers.html#Updating-Index-Buffers", null ]
      ] ],
      [ "Hardware Pixel Buffers", "_hardware-_buffers.html#Hardware-Pixel-Buffers", [
        [ "Textures", "_hardware-_buffers.html#Textures", [
          [ "Creating a texture", "_hardware-_buffers.html#Creating-a-texture", null ]
        ] ],
        [ "Getting a PixelBuffer", "_hardware-_buffers.html#Getting-a-PixelBuffer", null ],
        [ "Updating Pixel Buffers", "_hardware-_buffers.html#Updating-Pixel-Buffers", null ],
        [ "Blit from memory", "_hardware-_buffers.html#blitFromMemory", null ],
        [ "Direct memory locking", "_hardware-_buffers.html#Direct-memory-locking", null ],
        [ "Texture Types", "_hardware-_buffers.html#Texture-Types", null ],
        [ "Cube map textures", "_hardware-_buffers.html#Cube-map-textures", null ],
        [ "Pixel Formats", "_hardware-_buffers.html#Pixel-Formats", null ],
        [ "Colour channels", "_hardware-_buffers.html#Colour-channels", null ],
        [ "List of pixel formats", "_hardware-_buffers.html#Complete-list-of-pixel-formats", null ],
        [ "Pixel boxes", "_hardware-_buffers.html#Pixel-boxes", null ]
      ] ]
    ] ],
    [ "Shadows", "_shadows.html", [
      [ "Enabling shadows", "_shadows.html#Enabling-shadows", null ],
      [ "Opting out of shadows", "_shadows.html#Opting-out-of-shadows", null ],
      [ "Stencil Shadows", "_shadows.html#Stencil-Shadows", null ],
      [ "Texture-based Shadows", "_shadows.html#Texture_002dbased-Shadows", null ],
      [ "Configuring Texture Shadows", "_shadows.html#Configuring-Texture-Shadows", null ],
      [ "Texture shadows and vertex / fragment programs", "_shadows.html#texture_shadows_and_shaders", [
        [ "Integrated Texture Shadows", "_shadows.html#Integrated-Texture-Shadows", null ]
      ] ],
      [ "Modulative Shadows", "_shadows.html#Modulative-Shadows", null ],
      [ "Additive Light Masking", "_shadows.html#Additive-Light-Masking", [
        [ "Manually Categorising Illumination Passes", "_shadows.html#Manually-Categorising-Illumination-Passes", null ],
        [ "Pass Classification and Vertex Programs", "_shadows.html#Pass-Classification-and-Vertex-Programs", null ],
        [ "Static Lighting", "_shadows.html#Static-Lighting", null ]
      ] ]
    ] ],
    [ "Animation", "_animation.html", [
      [ "Animation State", "_animation.html#Animation-State", null ],
      [ "Skeletal Animation", "_animation.html#Skeletal-Animation", null ],
      [ "SceneNode Animation", "_animation.html#SceneNode-Animation", null ],
      [ "Vertex Animation", "_animation.html#Vertex-Animation", [
        [ "Morph Animation", "_animation.html#Morph-Animation", null ],
        [ "Pose Animation", "_animation.html#Pose-Animation", null ],
        [ "Combining Skeletal and Vertex Animation", "_animation.html#Combining-Skeletal-and-Vertex-Animation", null ]
      ] ],
      [ "Numeric Value Animation", "_animation.html#Numeric-Value-Animation", null ]
    ] ]
];
